

# DD-Code (Schema)


# 1. Protein



* Collection of proteins found to be related to LLPS (LLPS Positive and regulators)
* Current Data Sources:
    * [https://phasepro.elte.hu/](https://phasepro.elte.hu/) **<span style="text-decoration:underline;">phase_hu</span>**
        * Manually verified and highly trustable entries of 121 proteins (mostly drivers/scaffolds)
    * [http://db.phasep.pro/](http://db.phasep.pro/) 
        * phase_pro_1: V1 of database released in 2019
            * **<span style="text-decoration:underline;">phase_pro_1_rev</span>**: Manually reviewed where evidence includes experiments, including reconstituting an LLPS assembly of purified components in vitro, fluorescence recovery after photobleaching (FRAP) assay in vitro or in cell, droplets formation examined by immunofluorescence with fluorescent marker in cell
            * **<span style="text-decoration:underline;">phase_pro_1_unirev</span>**: Manually curated data from Uniprot cellular localisation in protein entries (nucleolus, P-granules etc.)
            * **<span style="text-decoration:underline;">phase_pro_1_ht</span>**: Literature research using keyword search on Pubmed articles, followed by computational screening
        * phase_pro_2: V2 of database released in 2021
            * **<span style="text-decoration:underline;">phase_pro_2_ps</span>**: LLPS information with higher level of verification as compared to the above 3. Contains annotation for self-phase-separating (scaffold/driver) and client
    * [http://llps.biocuckoo.cn/](http://llps.biocuckoo.cn/) **<span style="text-decoration:underline;">dr_llps</span>**
        * 9k+ proteins found to be LLPS with computational search followed by manual curation; Provides annotation for scaffolds (or drivers), clients and regulators (proteins aiding LLPS)
    * [http://llps.biocuckoo.cn/](http://llps.biocuckoo.cn/) **<span style="text-decoration:underline;">llps_db</span>**: In-vitro LLPS experiments done under multiple physicochemical conditions
        * **<span style="text-decoration:underline;">llps_db_1_comp</span>:** Experiments done with 1 protein member
        * **<span style="text-decoration:underline;">llps_db_2_comp</span>**: Experiments done with 2 protein members
        * **<span style="text-decoration:underline;">llps_db_more_comp</span>**: Experiments done with more than 2 protein members

<table>
  <tr>
   <td>
<strong>Attribute</strong>
   </td>
   <td><strong>Data Type</strong>
   </td>
   <td><strong>Description</strong>
   </td>
  </tr>
  <tr>
   <td><strong>uniprot_id</strong>
   </td>
   <td>string
   </td>
   <td>Unique identifier for the proteins collection; Fetched from Uniprot.org 
   </td>
  </tr>
  <tr>
   <td>uniprot_readable_id
   </td>
   <td>string
   </td>
   <td>Readable ID from Uniprot; Concatenation of uniprot ID and species name
   </td>
  </tr>
  <tr>
   <td>name
   </td>
   <td>string
   </td>
   <td>Common Name submitted or accepted for the protein as per Uniprot
   </td>
  </tr>
  <tr>
   <td>gene_name
   </td>
   <td>string
   </td>
   <td>Scientific Name of the Gene; Fetched from Uniprot.org
   </td>
  </tr>
  <tr>
   <td>species_name
   </td>
   <td>string
   </td>
   <td>Name of organism where the protein is found; Fetched from Uniprot.org
   </td>
  </tr>
  <tr>
   <td>species_tax_id
   </td>
   <td>string
   </td>
   <td>NCBI Taxonomy ID of organism where the protein is found; Fetched from Uniprot.org
   </td>
  </tr>
  <tr>
   <td>ensembl_id
   </td>
   <td>string
   </td>
   <td>ENSEMBL ID; Fetched from Uniprot.org (latest one)
   </td>
  </tr>
  <tr>
   <td>ensembl_gene_id
   </td>
   <td>string
   </td>
   <td>ENSEMBL ID of the gene;  Fetched from Uniprot.org (latest one)
   </td>
  </tr>
  <tr>
   <td>sequence
   </td>
   <td>string
   </td>
   <td>Amino Acid Sequence
   </td>
  </tr>
  <tr>
   <td>llps_ptms
   </td>
   <td>list of strings
   </td>
   <td>List of PTMs helping in LLPS of the protein; Data fetched from <strong><span style="text-decoration:underline;">phase_hu</span></strong>
<p>
PTM is identified by the <em>unique_name </em>from PTMs collection (1.1)
   </td>
  </tr>
  <tr>
   <td>function
   </td>
   <td>string
   </td>
   <td>Functional Description of protein;  Fetched from Uniprot.org
   </td>
  </tr>
  <tr>
   <td>functional_type
   </td>
   <td>categorical
   </td>
   <td>(Hierarchical annotation of) Role of the protein in a condensate. Possible values: 
<ol>

<li><strong><em>scaffold (or driver)</em></strong>: A protein that undergoes phase separation or self-assembles to form liquid droplets independent of other proteins, induces the formation of a condensate, or is essential for the integrity of a condensate. This protein is known to be a driver in at least one of the known condensates.

<li><strong><em>client</em></strong>: A protein that is part of a condensate, but is driven to the condensate by a driver protein. This protein is known to be a client in at least one of the known condensates, but never known to be a driver.

<li><strong><em>regulator</em></strong>: A protein that biochemically or enzymatically regulates the formation of a condensate, but is not a part of the condensate. This protein is never known to be a driver or client.

<p>
As of now:
<ul>

<li><strong><span style="text-decoration:underline;">dr_llps </span></strong>provides annotation for scaffolds, clients and regulator

<li><strong><span style="text-decoration:underline;">llps_db_1_comp</span></strong> are considered as scaffolds (or drivers); since self-phase-separate

<li><strong><span style="text-decoration:underline;">phase_pro_2_ps</span></strong> proteins have annotation for self/others-PS
</li>
</ul>
</li>
</ol>
   </td>
  </tr>
  <tr>
   <td>iupred_score
   </td>
   <td>list of float
   </td>
   <td>IUPred2A Prediction scores; fetched from <a href="https://iupred2a.elte.hu/">https://iupred2a.elte.hu/</a>;
<p>
List of score at each AA position; Score is from 0 to 1 indicating possibility of disorder
   </td>
  </tr>
</table>



## 1.1. PTM



* Only PTMs which lead to LLPS
* The **unique_name **is stored as a property of each protein as **llps_ptms **(foreign key reference; one-to-many)

<table>
  <tr>
   <td>
<strong>Attribute</strong>
   </td>
   <td><strong>Data Type</strong>
   </td>
   <td><strong>Description</strong>
   </td>
  </tr>
  <tr>
   <td><strong>unique_name</strong>
   </td>
   <td>string
   </td>
   <td>Position appended to name for uniqueness
   </td>
  </tr>
  <tr>
   <td>name
   </td>
   <td>string
   </td>
   <td>Readable Name/Commonly known as
   </td>
  </tr>
  <tr>
   <td>position
   </td>
   <td>string
   </td>
   <td>Position in protein sequence where the modification is taking place
   </td>
  </tr>
  <tr>
   <td>enzyme
   </td>
   <td>string
   </td>
   <td>
   </td>
  </tr>
  <tr>
   <td>effect_type
   </td>
   <td>categorical
   </td>
   <td>Either “weakens” or “strengthens”
   </td>
  </tr>
  <tr>
   <td>effect_description
   </td>
   <td>string
   </td>
   <td>Textual description of the effect of the PTM
   </td>
  </tr>
</table>



# 2. Condensate



* Collection name is **“condensate_parents”**
* Each entry refers to either a biomolecular membraneless cell organelle or a synthetically created one (in-vitro)
    * The boolean field **“is_experimental” **can be used to identify the type of condensate
* Each record is specific to an organism; meaning two separate entries for nucleolus of 9606 and 10090
    * Species could be one of those NCBI Taxonomy IDs we have for proteins or “Chimeras (0000)” for synthetic condensates with proteins from multiple organisms
* Condensate entries are merged as per a **_synonyms_** table which we use as ontology (can be produced on demand)

<table>
  <tr>
   <td>
<strong>Attribute</strong>
   </td>
   <td><strong>Data Type</strong>
   </td>
   <td><strong>Description</strong>
   </td>
  </tr>
  <tr>
   <td>name
   </td>
   <td>string
   </td>
   <td>Display Name of the condensate; For synthetic condensates it is the type of morpholgy (Eg: Droplet, Liquid Droplet, Transparent Solution)
   </td>
  </tr>
  <tr>
   <td><strong>canonical_id</strong>
   </td>
   <td>string
   </td>
   <td>Uniquely Identifiable name; For biomolecular condensates, it is the name concatenated with the species ID; for synthetic condensates, it starts with “<em>hybrid_</em>” concatenated with the proteins used in the experiment
   </td>
  </tr>
  <tr>
   <td>synonyms
   </td>
   <td>list of strings
   </td>
   <td>List of names (from source DBs), that refer to the same condensate; Data as per <strong><em>synonyms</em></strong> table
   </td>
  </tr>
  <tr>
   <td>species_name
   </td>
   <td>string
   </td>
   <td>Name of Organism where the proteins are found; “Chimeras” for condensates with proteins from more than 1 condensate
   </td>
  </tr>
  <tr>
   <td>species_tax_id
   </td>
   <td>string
   </td>
   <td>NCBI Taxonomy ID of the organism; 0000 for Chimeras
   </td>
  </tr>
  <tr>
   <td>proteins
   </td>
   <td>list of strings
   </td>
   <td>List of all proteins in this condensate. Should be a superset of scaffolds and their clients.
<p>
Protein is identified by <em>uniport_id </em>from the proteins collections(1)
   </td>
  </tr>
  <tr>
   <td>biomarkers
   </td>
   <td>list of strings
   </td>
   <td>List of protein Uniprot IDs which are biomarkers for this condensate
   </td>
  </tr>
  <tr>
   <td>is_experimental
   </td>
   <td>boolean
   </td>
   <td>Two categories of condensates:
<ol>

<li>True: Synthetically prepared

<li>False: Biomolecular Condensate (Membraneless Cell Organelle)
</li>
</ol>
   </td>
  </tr>
  <tr>
   <td>protein_pubmed_ids
   </td>
   <td>dict [string → list of strings]
   </td>
   <td>List of publications (represented by pubmed IDs) per protein in the condensate showing evidence for the respective protein to be a part of the condensate.
<p>
The field can be empty completely for some condensates (Eg: synthetic ones), or not have a key-value pair for some proteins.
<p>
Key: Protein uniprot ID; Value: List of pubmed IDs
   </td>
  </tr>
  <tr>
   <td>protein_source_db_tags
   </td>
   <td>dict [string → list of strings]
   </td>
   <td>List of tags (representing source databases as listed for Proteins) per protein in the condensate showing the source of this protein-condensate mapping.
<p>
The field is always present for all proteins in a condensate (at least till now since 11-11-2021)
<p>
Key: Protein uniprot ID; Value: List of <strong><em>source_db_tags</em></strong>
   </td>
  </tr>
</table>



## 2.1. Experiment



* In-vitro experiments done at different physicochemical conditions (temperature, PH, concentrations) trying to identify single or group of proteins’ possibility of phase-separation
* As of now (11-11-2021), the source of such information is **<span style="text-decoration:underline;">llps_db</span>**
* Each record corresponds to a separate experiment, which has one property as the **“condensate_id”**; This represents the condensate group from the condensates collection (usually synthetic ones)

<table>
  <tr>
   <td>
<strong>Attribute</strong>
   </td>
   <td><strong>Data Type</strong>
   </td>
   <td><strong>Description</strong>
   </td>
  </tr>
  <tr>
   <td><strong>exp_id</strong>
   </td>
   <td>string
   </td>
   <td>Unique Identifier for an experiment
   </td>
  </tr>
  <tr>
   <td>publication_link
   </td>
   <td>string
   </td>
   <td>Link to publication describing the experiment (Pubmed Article)
   </td>
  </tr>
  <tr>
   <td>condensate_id
   </td>
   <td>string
   </td>
   <td>Unique Identifier (canonical_id) of the condensate; The experiment was done using the proteins of this condensate (mostly synthetic)
   </td>
  </tr>
  <tr>
   <td>morphology
   </td>
   <td>categorical
   </td>
   <td>Observation of the experiment’s outcome; Type of the solution (possibly post LLPS)
<p>
Example: Droplet, Liquid Droplet, Transparent Solution
   </td>
  </tr>
  <tr>
   <td>solute_concentrations
   </td>
   <td>string
   </td>
   <td>Semi-colon separated list of concentration for each protein in the condensate
<p>
The protein mentioned as per common name or some modified version of the protein (could be normalised better)
   </td>
  </tr>
  <tr>
   <td>temperature
   </td>
   <td>float
   </td>
   <td>The temperature at which the experiment was conducted; RT means room temperature
   </td>
  </tr>
  <tr>
   <td>ph_value
   </td>
   <td>float
   </td>
   <td>PH of the experimental solution
   </td>
  </tr>
  <tr>
   <td>salt
   </td>
   <td>list of documents
   </td>
   <td>Each salt is identified by another set of attributes (embedded here itself; no FK)

<table>
  <tr>
   <td><strong>Attribute</strong>
   </td>
   <td><strong>Data Type</strong>
   </td>
   <td><strong>Description</strong>
   </td>
  </tr>
  <tr>
   <td>type
   </td>
   <td>string
   </td>
   <td>Salt Compound
   </td>
  </tr>
  <tr>
   <td>concentration
   </td>
   <td>float
   </td>
   <td>Conc in mM
   </td>
  </tr>
</table>


   </td>
  </tr>
  <tr>
   <td>is_phase_separated

   </td>
   <td>boolean

   </td>
   <td>Under given conditions, does phase separation take place?

   </td>
  </tr>
  <tr>
   <td>detection_method

   </td>
   <td>string

   </td>
   <td>Observation technique for LLPS outcome: FRAP, Microscopy etc.

   </td>
  </tr>
</table>

